
From: Kevin Corry <kevcorry@us.ibm.com>

DM: Add static and __init qualifiers. [Dave Olien]

Signed-off-by:  Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/md/dm-ioctl.c  |   14 +++++++-------
 25-akpm/drivers/md/dm-target.c |    3 ++-
 25-akpm/drivers/md/dm.c        |    6 ++++--
 25-akpm/drivers/md/dm.h        |    2 --
 4 files changed, 13 insertions(+), 12 deletions(-)

diff -puN drivers/md/dm.c~dm-add-static-and-__init-qualifiers drivers/md/dm.c
--- 25/drivers/md/dm.c~dm-add-static-and-__init-qualifiers	Wed May 26 15:43:19 2004
+++ 25-akpm/drivers/md/dm.c	Wed May 26 15:43:19 2004
@@ -93,7 +93,7 @@ struct mapped_device {
 static kmem_cache_t *_io_cache;
 static kmem_cache_t *_tio_cache;
 
-static __init int local_init(void)
+static int __init local_init(void)
 {
 	int r;
 
@@ -678,6 +678,8 @@ static int next_free_minor(unsigned int 
 	return r;
 }
 
+static struct block_device_operations dm_blk_dops;
+
 /*
  * Allocate and initialise a blank device with a given minor.
  */
@@ -1093,7 +1095,7 @@ int dm_suspended(struct mapped_device *m
 	return test_bit(DMF_SUSPENDED, &md->flags);
 }
 
-struct block_device_operations dm_blk_dops = {
+static struct block_device_operations dm_blk_dops = {
 	.open = dm_blk_open,
 	.release = dm_blk_close,
 	.owner = THIS_MODULE
diff -puN drivers/md/dm.h~dm-add-static-and-__init-qualifiers drivers/md/dm.h
--- 25/drivers/md/dm.h~dm-add-static-and-__init-qualifiers	Wed May 26 15:43:19 2004
+++ 25-akpm/drivers/md/dm.h	Wed May 26 15:43:19 2004
@@ -31,8 +31,6 @@
 
 #define SECTOR_SHIFT 9
 
-extern struct block_device_operations dm_blk_dops;
-
 /*
  * List of devices that a metadevice uses and should open/close.
  */
diff -puN drivers/md/dm-ioctl.c~dm-add-static-and-__init-qualifiers drivers/md/dm-ioctl.c
--- 25/drivers/md/dm-ioctl.c~dm-add-static-and-__init-qualifiers	Wed May 26 15:43:19 2004
+++ 25-akpm/drivers/md/dm-ioctl.c	Wed May 26 15:43:19 2004
@@ -46,7 +46,7 @@ struct vers_iter {
 static struct list_head _name_buckets[NUM_BUCKETS];
 static struct list_head _uuid_buckets[NUM_BUCKETS];
 
-void dm_hash_remove_all(void);
+static void dm_hash_remove_all(void);
 
 /*
  * Guards access to both hash tables.
@@ -61,7 +61,7 @@ static void init_buckets(struct list_hea
 		INIT_LIST_HEAD(buckets + i);
 }
 
-int dm_hash_init(void)
+static int dm_hash_init(void)
 {
 	init_buckets(_name_buckets);
 	init_buckets(_uuid_buckets);
@@ -69,7 +69,7 @@ int dm_hash_init(void)
 	return 0;
 }
 
-void dm_hash_exit(void)
+static void dm_hash_exit(void)
 {
 	dm_hash_remove_all();
 	devfs_remove(DM_DIR);
@@ -195,7 +195,7 @@ static int unregister_with_devfs(struct 
  * The kdev_t and uuid of a device can never change once it is
  * initially inserted.
  */
-int dm_hash_insert(const char *name, const char *uuid, struct mapped_device *md)
+static int dm_hash_insert(const char *name, const char *uuid, struct mapped_device *md)
 {
 	struct hash_cell *cell;
 
@@ -234,7 +234,7 @@ int dm_hash_insert(const char *name, con
 	return -EBUSY;
 }
 
-void __hash_remove(struct hash_cell *hc)
+static void __hash_remove(struct hash_cell *hc)
 {
 	/* remove from the dev hash */
 	list_del(&hc->uuid_list);
@@ -246,7 +246,7 @@ void __hash_remove(struct hash_cell *hc)
 	free_cell(hc);
 }
 
-void dm_hash_remove_all(void)
+static void dm_hash_remove_all(void)
 {
 	int i;
 	struct hash_cell *hc;
@@ -262,7 +262,7 @@ void dm_hash_remove_all(void)
 	up_write(&_hash_lock);
 }
 
-int dm_hash_rename(const char *old, const char *new)
+static int dm_hash_rename(const char *old, const char *new)
 {
 	char *new_name, *old_name;
 	struct hash_cell *hc;
diff -puN drivers/md/dm-target.c~dm-add-static-and-__init-qualifiers drivers/md/dm-target.c
--- 25/drivers/md/dm-target.c~dm-add-static-and-__init-qualifiers	Wed May 26 15:43:19 2004
+++ 25-akpm/drivers/md/dm-target.c	Wed May 26 15:43:19 2004
@@ -7,6 +7,7 @@
 #include "dm.h"
 
 #include <linux/module.h>
+#include <linux/init.h>
 #include <linux/kmod.h>
 #include <linux/bio.h>
 #include <linux/slab.h>
@@ -181,7 +182,7 @@ static struct target_type error_target =
 	.map  = io_err_map,
 };
 
-int dm_target_init(void)
+int __init dm_target_init(void)
 {
 	return dm_register_target(&error_target);
 }
_
